#coding:utf-8

__version__ = '3.11.27.1'
__git_version__ = '60d7aecc78471c8dfbe6a341673ff6c7b97f0253'
__release_time__ = '2013-11-27 11:12:05'

#import os
#PROJECT_ROOT = os.path.abspath(os.path.dirname(__file__))

#from .log import init_log
#init_log()